@@ -47,44 +47,44 @@ TYPE_FLATS = 0
 TYPE_GROUP = 1
 
 HQ_HOSTS = [
-    ('深圳双线主站1', '110.41.147.114', '7709'),
-    ('深圳双线主站2', '8.129.13.54', '7709'),
-    ('深圳双线主站3', '120.24.149.49', '7709'),
-    ('深圳双线主站4', '47.113.94.204', '7709'),
-    ('深圳双线主站5', '8.129.174.169', '7709'),
-    ('深圳双线主站6', '110.41.154.219', '7709'),
-    ('上海双线主站1', '124.70.176.52', '7709'),
-    ('上海双线主站2', '47.100.236.28', '7709'),
-    ('上海双线主站3', '101.133.214.242', '7709'),
-    ('上海双线主站4', '47.116.21.80', '7709'),
-    ('上海双线主站5', '47.116.105.28', '7709'),
-    ('上海双线主站6', '124.70.199.56', '7709'),
-    ('北京双线主站1', '121.36.54.217', '7709'),
-    ('北京双线主站2', '121.36.81.195', '7709'),
-    ('北京双线主站3', '123.249.15.60', '7709'),
-    ('广州双线主站1', '124.71.85.110', '7709'),
-    ('广州双线主站2', '139.9.51.18', '7709'),
-    ('广州双线主站3', '139.159.239.163', '7709'),
-    ('上海双线主站7', '106.14.201.131', '7709'),
-    ('上海双线主站8', '106.14.190.242', '7709'),
-    ('上海双线主站9', '121.36.225.169', '7709'),
-    ('上海双线主站10', '123.60.70.228', '7709'),
-    ('上海双线主站11', '123.60.73.44', '7709'),
-    ('上海双线主站12', '124.70.133.119', '7709'),
-    ('上海双线主站13', '124.71.187.72', '7709'),
-    ('上海双线主站14', '124.71.187.122', '7709'),
-    ('武汉电信主站1', '119.97.185.59', '7709'),
-    ('深圳双线主站7', '47.107.64.168', '7709'),
-    ('北京双线主站4', '124.70.75.113', '7709'),
-    ('广州双线主站4', '124.71.9.153', '7709'),
-    ('上海双线主站15', '123.60.84.66', '7709'),
-    ('深圳双线主站8', '47.107.228.47', '7719'),
-    ('北京双线主站5', '120.46.186.223', '7709'),
-    ('北京双线主站6', '124.70.22.210', '7709'),
-    ('北京双线主站7', '139.9.133.247', '7709'),
-    ('广州双线主站5', '116.205.163.254', '7709'),
-    ('广州双线主站6', '116.205.171.132', '7709'),
-    ('广州双线主站7', '116.205.183.150', '7709')
+    ('深圳双线主站1', '110.41.147.114', 7709),
+    ('深圳双线主站2', '8.129.13.54', 7709),
+    ('深圳双线主站3', '120.24.149.49', 7709),
+    ('深圳双线主站4', '47.113.94.204', 7709),
+    ('深圳双线主站5', '8.129.174.169', 7709),
+    ('深圳双线主站6', '110.41.154.219', 7709),
+    ('上海双线主站1', '124.70.176.52', 7709),
+    ('上海双线主站2', '47.100.236.28', 7709),
+    ('上海双线主站3', '101.133.214.242', 7709),
+    ('上海双线主站4', '47.116.21.80', 7709),
+    ('上海双线主站5', '47.116.105.28', 7709),
+    ('上海双线主站6', '124.70.199.56', 7709),
+    ('北京双线主站1', '121.36.54.217', 7709),
+    ('北京双线主站2', '121.36.81.195', 7709),
+    ('北京双线主站3', '123.249.15.60', 7709),
+    ('广州双线主站1', '124.71.85.110', 7709),
+    ('广州双线主站2', '139.9.51.18', 7709),
+    ('广州双线主站3', '139.159.239.163', 7709),
+    ('上海双线主站7', '106.14.201.131', 7709),
+    ('上海双线主站8', '106.14.190.242', 7709),
+    ('上海双线主站9', '121.36.225.169', 7709),
+    ('上海双线主站10', '123.60.70.228', 7709),
+    ('上海双线主站11', '123.60.73.44', 7709),
+    ('上海双线主站12', '124.70.133.119', 7709),
+    ('上海双线主站13', '124.71.187.72', 7709),
+    ('上海双线主站14', '124.71.187.122', 7709),
+    ('武汉电信主站1', '119.97.185.59', 7709),
+    ('深圳双线主站7', '47.107.64.168', 7709),
+    ('北京双线主站4', '124.70.75.113', 7709),
+    ('广州双线主站4', '124.71.9.153', 7709),
+    ('上海双线主站15', '123.60.84.66', 7709),
+    ('深圳双线主站8', '47.107.228.47', 7719),
+    ('北京双线主站5', '120.46.186.223', 7709),
+    ('北京双线主站6', '124.70.22.210', 7709),
+    ('北京双线主站7', '139.9.133.247', 7709),
+    ('广州双线主站5', '116.205.163.254', 7709),
+    ('广州双线主站6', '116.205.171.132', 7709),
+    ('广州双线主站7', '116.205.183.150', 7709)
 ]
 
 EX_HOSTS = [
