@@ -2,21 +2,20 @@
 # @Time    : 2021/10/9 10:56
 # @Function:
 import datetime
-import httpx
-import pandas as pd
 import re
 import time
 from pathlib import Path
+
+import httpx
+import pandas as pd
+from py_mini_racer import py_mini_racer
 from tenacity import retry
 from tenacity import stop_after_attempt
 from tenacity import wait_fixed
 
 from mootdx import get_config_path
-from mootdx.logger import logger
-
-
-from py_mini_racer import py_mini_racer
 from mootdx.consts import return_last_value
+from mootdx.logger import logger
 
 hk_js_decode = """
 function d(t) {
@@ -310,20 +309,22 @@ function d(t) {
 
 
 @retry(wait=wait_fixed(2), retry_error_callback=return_last_value, stop=stop_after_attempt(5))
-def holiday2(date=False, save=True) -> pd.DataFrame:
+def holiday2(date=False) -> pd.DataFrame:
     """交易日历-历史数据
     :return: 交易日历
     :rtype: pandas.DataFrame
     """
-    # cache_file = get_config_path('holiday.csv')
+    cache_file = get_config_path('holiday2.plk')
     temp_df = None
 
-    # if Path(cache_file).exists():
-    #     df = pd.read_csv(cache_file)
-    #     if not df.loc[df['year'] == datetime.datetime.now().year].empty:
-    #         temp_df = df
+    if Path(cache_file).exists():
+        df = pd.read_pickle(cache_file)
+        if not df.loc[df['year'] == datetime.datetime.now().year].empty:
+            logger.debug("调用缓存")
+            temp_df = df
 
     if type(temp_df) is not pd.DataFrame:
+        logger.debug("调用远程接口")
         client = httpx.Client(verify=False)
 
         url = "https://finance.sina.com.cn/realstock/company/klc_td_sh.txt"
@@ -345,9 +346,7 @@ def holiday2(date=False, save=True) -> pd.DataFrame:
 
         temp_df = pd.DataFrame(temp_list, columns=["date"])
         temp_df["year"] = pd.DatetimeIndex(temp_df["date"]).year
-
-        # 保存缓存
-        # save and temp_df.to_csv(cache_file)
+        temp_df.to_pickle(cache_file)
 
     if date:
 
@@ -362,7 +361,7 @@ def holiday2(date=False, save=True) -> pd.DataFrame:
 
 
 def holiday(date=None, format_=None, country=None, result=False):
-    # cache_file = get_config_path('holiday.plk')
+    cache_file = get_config_path('holiday.plk')
 
     format_ = format_ if format_ else "%Y-%m-%d"
     country = country if country else "中国"
@@ -376,17 +375,20 @@ def holiday(date=None, format_=None, country=None, result=False):
         logger.exception("日期或者日期格式错误!")
         raise ex
 
-    # if Path(cache_file).exists() and time.localtime(Path(cache_file).stat().st_mtime).tm_year == time.localtime(time.time()).tm_year:
-    #     df = pd.read_pickle(cache_file)
-    # else:
+    if Path(cache_file).exists() and time.localtime(Path(cache_file).stat().st_mtime).tm_year == time.localtime(time.time()).tm_year:
+        df = pd.read_pickle(cache_file)
+        logger.debug("调用缓存")
+    else:
+        logger.debug("调用远程接口")
+        res = httpx.get("https://www.tdx.com.cn/url/holiday/")
+        res.encoding = "gbk"
 
-    res = httpx.get("https://www.tdx.com.cn/url/holiday/")
-    ret = re.findall(r'<textarea id="data" style="display:none;">([\s\w\d\W]+)</textarea>', res.text, re.M)[0].strip()
-    day = [d.split("|")[:4] for d in ret.split("\n")]
+        ret = re.findall(r'<textarea id="data" style="display:none;">([\s\w\d\W]+)</textarea>', res.text, re.M)[0].strip()
+        day = [d.split("|")[:4] for d in ret.split("\n")]
 
-    df = pd.DataFrame(day, columns=["日期", "节日", "国家", "交易所"], dtype=str)
-    df.index = pd.to_datetime(df["日期"].astype("str"), format="%Y%m%d")
-    # df.to_pickle(cache_file)
+        df = pd.DataFrame(day, columns=["日期", "节日", "国家", "交易所"], dtype=str)
+        df.index = pd.to_datetime(df["日期"].astype("str"), format="%Y%m%d")
+        df.to_pickle(cache_file)
 
     if country not in list(set(df["国家"].values)):
         raise ValueError(f"没有该国家`{country}`的交易日数据")
@@ -394,11 +396,13 @@ def holiday(date=None, format_=None, country=None, result=False):
     df = df[df["国家"] == country]
     df = df[df.index.isin([date])]
 
-    logger.error(df)
+    logger.debug(date)
 
     if result:
         return df
 
+    logger.debug(date.weekday())
+
     return not df.empty or date.weekday() >= 5
 
 
